---
title: Virtualization
page_title: Virtualization - ComboBox - Kendo UI for Vue
description: "Use the virtualization features of the Kendo UI ComboBox wrapper for Vue which allow you to handle large datasets."
slug: virtualization_combobox
position: 4
---

# Virtualization

Virtualization allows you to display large sets of data.

Regardless of the dataset size, the UI virtualization technique uses a fixed amount of list items in the popup list of the component. When the list is scrolled, the ComboBox reuses the existing items to display the relevant data instead of creating new data.

The following example demonstrates how to set the minimum configuration of the ComboBox and the DataSource to enable the virtualization.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource"
                      :type="'odata'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Orders'"
                      :schema-model-fields="fields"
                      :server-filtering="true"
                      :server-paging="true"
                      :page-size="40">
    </kendo-datasource>
    <kendo-combobox ref="combobox"
                    :data-source-ref="'datasource'"
                    :data-text-field="'ShipName'"
                    :data-value-field="'OrderID'"
                    :virtual-item-height="26"
                    :virtual-value-mapper="valueMapperFunction"
                    :height="260"
                    :template="itemTemplate"
                    style="width:400px;">
    </kendo-combobox>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    methods: {
        convertValues (value) {
            var data = {}
            value = $.isArray(value) ? value : [value]

            for (var idx = 0; idx < value.length; idx++) {
                data['values[' + idx + ']'] = value[idx]
            }

            return data
        },
        valueMapperFunction: function (options) {
            var that = this;

            $.ajax({
                url: 'https://demos.telerik.com/kendo-ui/service/Orders/ValueMapper',
                type: 'GET',
                dataType: 'jsonp',
                data: that.convertValues(options.value),
                success: function (data) {
                    options.success(data)
                }
            })
        },
    },
    data: {
        fields: {
            OrderID: { type: 'number' },
            Freight: { type: 'number' },
            ShipName: { type: 'string' },
            OrderDate: { type: 'date' },
            ShipCity: { type: 'string' }
        },
        itemTemplate: '<strong>#= OrderID #</strong> - #= ShipName #, #= ShipCountry #'
    },
    mounted() {
        var combobox = this.$refs.combobox.kendoWidget()
        combobox.value(10600)
    }
})
```

## Suggested Links

* [Kendo UI ComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/combobox/overview)
* [API Reference of the ComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/combobox)
