---
title: Columns
page_title: Columns - MultiColumnComboBox - Kendo UI for Vue
description: "Configure the columns rendered in the Kendo UI MultiColumnComboBox wrapper for Vue drop-down."
slug: columns_multicolumncombobox
position: 3
---

# Columns

The MultiColumnComboBox supports options for configuring the behavior of its columns.

To manage the columns of the MultiColumnComboBox, either:
* [Use the `kendo-multicolumncombobox-columns` component](#toc-using-the-kendo-multicolumncombobox-columns-component), or
* [Configure an object in the Vue data](#toc-using-the-data-vue-object).

For more information on the available props, refer to the [`multicolumncombobox.columns`](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox/configuration/columns) configuration.

## Using the kendo-multicolumncombobox-columns Component

The following example demonstrates how to set the inline initialization of the `kendo-multicolumncombobox-columns` component.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-text-field="'ProductName'"
                               :data-value-field="'ProductID'"
                               :data-source="dataSourceArray"
                               style="width:650px">
        <kendo-multicolumncombobox-column :field="'ProductID'"
                                          :title="'ID'"
                                          :width="70">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'ProductName'"
                                          :title="'Product Name'">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'Discontinued'">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitPrice'"
                                          :title="'Unit Price'"
                                          :format="'{0:c}'"
                                          :width="100">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitsInStock'"
                                          :title="'Units in Stock'"
                                          :width="150">
        </kendo-multicolumncombobox-column>
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
   data () {
		return {
        dataSourceArray: [{
                "ProductID": 1,
                "ProductName": "Chai",
                "UnitPrice": 18,
                "UnitsInStock": 39,
                "Discontinued": false
            },
            {
                "ProductID": 4,
                "ProductName": "Chef Anton",
                "UnitPrice": 22,
                "UnitsInStock": 53,
                "Discontinued": false
            },
            {
                "ProductID": 5,
                "ProductName": "Chef Gumbo Mix",
                "UnitPrice": 21.35,
                "UnitsInStock": 0,
                "Discontinued": true
            },
            {
                "ProductID": 6,
                "ProductName": "Boysenberry Spread",
                "UnitPrice": 25,
                "UnitsInStock": 120,
                "Discontinued": false
            }]
        }
    }
})
```

## Using the data Vue Object

The following example demonstrates how to use the `data` object to specify the columns of the MultiColumnComboBox.

```html
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-text-field="'ProductName'"
                               :data-value-field="'ProductID'"
                               :data-source="dataSourceArray"
                               :columns="columns"
                               style="width:200px">
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
   data () {
		return {
        columns: [
            { field: "ProductName", title: "Product Name", width: 180 },
            { field: "UnitPrice", title: "Unit Price", format: "{0:c}", width: 150 },
            { field: "UnitsInStock", title: "Units In Stock", width: 150 },
            { field: "Discontinued", width: 150 }
        ],
        dataSourceArray: [{
                "ProductID": 1,
                "ProductName": "Chai",
                "UnitPrice": 18,
                "UnitsInStock": 39,
                "Discontinued": false
            },
            {
                "ProductID": 4,
                "ProductName": "Chef Anton",
                "UnitPrice": 22,
                "UnitsInStock": 53,
                "Discontinued": false
            },
            {
                "ProductID": 5,
                "ProductName": "Chef Gumbo Mix",
                "UnitPrice": 21.35,
                "UnitsInStock": 0,
                "Discontinued": true
            },
            {
                "ProductID": 6,
                "ProductName": "Boysenberry Spread",
                "UnitPrice": 25,
                "UnitsInStock": 120,
                "Discontinued": false
            }]
        }
    }
})
```

## Suggested Links

* [Kendo UI MultiColumnComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multicolumncombobox/overview)
* [API Reference of the MultiColumnComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox)
