---
title: Templates
page_title: Templates - MultiColumnComboBox - Kendo UI for Vue
description: "Customize the content of the suggested list items and the suggested list elements of a Kendo UI MultiColumnComboBox wrapper for Vue."
slug: templates_multicolumncombobox
position: 9
---

# Templates

The MultiColumnComboBox provides the means needed to define column template, column headerTemplate and footerTemplate.

The `template` and the `header-template` could be defined for each of the columns available in the widget. The `footer-template` and the `no-data-template`, on the other hand, are defined for the entire popup of the widget. The templates in the MultiColumnComboBox are rendered by using the [Kendo UI templates](https://docs.telerik.com/kendo-ui/framework/templates/overview).

## Column Templates

The column `template` manages the way a given column values in the MultiColumnComboBox popup are rendered.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-text-field="'ProductName'"
                               :data-value-field="'UnitsInStock'"
                               :data-source="dataSourceArray"
                               style="width:300px">
        <kendo-multicolumncombobox-column :field="'ProductName'"
                                          :title="'Product Name'"
                                          :template="nameColumnTemplate"
                                          :width="250">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'Discontinued'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitPrice'"
                                          :title="'Unit Price'"
                                          :format="'{0:c}'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitsInStock'"
                                          :title="'Units in Stock'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            nameColumnTemplate: "Name: <strong>#: ProductName #</strong>",
            dataSourceArray: [{
                "ProductID": 1,
                "ProductName": "Chai",
                "UnitPrice": 18,
                "UnitsInStock": 39,
                "Discontinued": false
            },
            {
                "ProductID": 4,
                "ProductName": "Chef Anton",
                "UnitPrice": 22,
                "UnitsInStock": 53,
                "Discontinued": false
            },
            {
                "ProductID": 5,
                "ProductName": "Chef Gumbo Mix",
                "UnitPrice": 21.35,
                "UnitsInStock": 0,
                "Discontinued": true
            },
            {
                "ProductID": 6,
                "ProductName": "Boysenberry Spread",
                "UnitPrice": 25,
                "UnitsInStock": 120,
                "Discontinued": false
            }]
        }
    }
})
```

## Header Templates

The column `header-template` defines the header appearance and content for a givin column.

```html
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-text-field="'ProductName'"
                               :data-value-field="'UnitsInStock'"
                               :data-source="dataSourceArray"
                               style="width:300px">
        <kendo-multicolumncombobox-column :field="'ProductName'"
                                          :title="'Product Name'"
                                          :header-template="nameColumnHeaderTemplate"
                                          :width="250">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'Discontinued'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitPrice'"
                                          :title="'Unit Price'"
                                          :format="'{0:c}'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitsInStock'"
                                          :title="'Units in Stock'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            nameColumnHeaderTemplate: "<strong>The Name of the Product</strong>",
            dataSourceArray: [{
                "ProductID": 1,
                "ProductName": "Chai",
                "UnitPrice": 18,
                "UnitsInStock": 39,
                "Discontinued": false
            },
            {
                "ProductID": 4,
                "ProductName": "Chef Anton",
                "UnitPrice": 22,
                "UnitsInStock": 53,
                "Discontinued": false
            },
            {
                "ProductID": 5,
                "ProductName": "Chef Gumbo Mix",
                "UnitPrice": 21.35,
                "UnitsInStock": 0,
                "Discontinued": true
            },
            {
                "ProductID": 6,
                "ProductName": "Boysenberry Spread",
                "UnitPrice": 25,
                "UnitsInStock": 120,
                "Discontinued": false
            }]
        }
    }
})
```

## Footer Templates

The `footer-template` manages the way the popup footer of the MultiColumnComboBox is rendered. The footer is re-rendered on every change of the Data Source. The context of the template is the component itself.

```html
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-text-field="'ProductName'"
                               :data-value-field="'UnitsInStock'"
                               :data-source="dataSourceArray"
                               :footer-template="footerTemplate"
                               style="width:300px">
        <kendo-multicolumncombobox-column :field="'ProductName'"
                                          :title="'Product Name'"
                                          :width="250">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'Discontinued'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitPrice'"
                                          :title="'Unit Price'"
                                          :format="'{0:c}'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'UnitsInStock'"
                                          :title="'Units in Stock'"
                                          :width="120">
        </kendo-multicolumncombobox-column>
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            footerTemplate: "Total <strong>#: instance.dataSource.total() #</strong> items found",
            dataSourceArray: [{
                "ProductID": 1,
                "ProductName": "Chai",
                "UnitPrice": 18,
                "UnitsInStock": 39,
                "Discontinued": false
            },
            {
                "ProductID": 4,
                "ProductName": "Chef Anton",
                "UnitPrice": 22,
                "UnitsInStock": 53,
                "Discontinued": false
            },
            {
                "ProductID": 5,
                "ProductName": "Chef Gumbo Mix",
                "UnitPrice": 21.35,
                "UnitsInStock": 0,
                "Discontinued": true
            },
            {
                "ProductID": 6,
                "ProductName": "Boysenberry Spread",
                "UnitPrice": 25,
                "UnitsInStock": 120,
                "Discontinued": false
            }]
        }
    }
})
```

## No-Data Templates

The MultiColumnComboBox displays the `no-data-template` in its popup when the data source is empty.

> When the `noDataTemplate` option is defined, the component always opens the popup element.

```html
<div id="vueapp" class="vue-app">
    <kendo-multicolumncombobox :data-source="dataSourceArray"
                               :no-data-template="noDataTemplate">
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            noDataTemplate: "No Data!",
            dataSourceArray: []
        }
    }
})
```

## Suggested Links

* [Kendo UI MultiColumnComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multicolumncombobox/overview)
* [API Reference of the MultiColumnComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox)
