---
title: Grouping
page_title: Grouping - MultiSelect - Kendo UI for Vue
description: "Group the data during input while using the Kendo UI MultiSelect wrapper for Vue."
slug: grouping_multiselect
position: 5
---

# Grouping

Grouping allows you to display data items which are categorized by a specific model field.

> * The grouped data is sorted either in ascending or descending order.
> * To group the data in a specific order, use [server grouping](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource#configuration-serverGrouping).

For more information on the grouping functionality of the Data Source, refer to the article on the [`group`](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource#configuration-group) configuration.

To configure the rendering of the group titles, use the [`groupTemplate`](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect#configuration-groupTemplate) and [`fixedGroupedTemplate`](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect#configuration-fixedGroupTemplate) templates of the component.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource"
                      :type="'odata'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Customers'"
                      :group-field="'Country'">
    </kendo-datasource>
    <kendo-multiselect :data-source-ref="'datasource'"
                       :data-text-field="'ContactName'"
                       :data-value-field="'ContactID'"
                       :filter="'contains'">
    </kendo-multiselect>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp"
})
```

## Suggested Links

* [Kendo UI MultiSelect for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multiselect/overview)
* [API Reference of the MultiSelect Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect)
